import { PluginKey } from '@bangle.dev/pm';
import { usePluginState, useEditorViewContext } from '@bangle.dev/react';
import PropTypes from 'prop-types';
import React from 'react';
import reactDOM from 'react-dom';
import { hasComponentInSchema } from './helper';
import { LinkSubMenu } from './LinkSubMenu';
import { Menu } from './Menu';
import { BoldButton, BulletListButton, CodeButton, FloatingLinkButton, HeadingButton, ItalicButton, TodoListButton, } from './MenuButtons';
import { MenuGroup } from './MenuGroup';
export function FloatingMenu({ menuKey, renderMenuType = ({ type, menuKey, editorState }) => {
    if (type === 'defaultMenu') {
        //  NOTE these hasComponentInSchema checks exist because this is a default callback value
        // and it cannot make any assumptions on the schema.
        // The API is designed so that the user overrides this with their own callback and since they
        // would know the schema, they wouldnt need such checks.
        return (React.createElement(Menu, null,
            React.createElement(MenuGroup, null,
                hasComponentInSchema(editorState, 'bold') && React.createElement(BoldButton, null),
                hasComponentInSchema(editorState, 'italic') && React.createElement(ItalicButton, null),
                hasComponentInSchema(editorState, 'code') && React.createElement(CodeButton, null),
                hasComponentInSchema(editorState, 'link') && (React.createElement(FloatingLinkButton, { menuKey: menuKey }))),
            React.createElement(MenuGroup, null,
                hasComponentInSchema(editorState, 'heading') && (React.createElement(HeadingButton, { level: 2 })),
                hasComponentInSchema(editorState, 'heading') && (React.createElement(HeadingButton, { level: 3 })),
                hasComponentInSchema(editorState, 'bulletList') && (React.createElement(BulletListButton, null)),
                hasComponentInSchema(editorState, 'bulletList') && (React.createElement(TodoListButton, null)))));
    }
    if (type === 'linkSubMenu') {
        return (React.createElement(Menu, null,
            React.createElement(LinkSubMenu, null)));
    }
    return null;
}, }) {
    const menuState = usePluginState(menuKey);
    const view = useEditorViewContext();
    const renderElement = renderMenuType({
        type: menuState.type,
        menuKey,
        editorState: view.state,
    });
    return renderElement
        ? reactDOM.createPortal(renderElement, menuState.tooltipContentDOM)
        : null;
}
FloatingMenu.propTypes = {
    menuKey: PropTypes.instanceOf(PluginKey).isRequired,
    renderMenuType: PropTypes.func,
};
//# sourceMappingURL=FloatingMenu.js.map